@@ -328,6 +328,33 @@ def edges_to_undir_graph(edges: list, ctx: Context) -> dict:
     return graph
 
 
+def graph_distance(
+    graph: dict, vert1, vert2, prev: list = []
+) -> list[list[int]]:
+    """Find the distance from vert1 to vert2 in a directed graph
+
+    Parameters:
+    graph: `dict[Vertex, list[Vertex]]`\\
+    A dictionary where keys are vertices and values are lists of
+    neighboring vertices
+    prev: `list[Vertex]`\\
+    A list of previously visited vertices, to avoid going in cycles"""
+    if vert1 == vert2:
+        return 0
+    # I know this is the American spelling, but it's shorter than neighbour
+    neighbors = [neighbor for neighbor in graph[vert1] if neighbor not in prev]
+    if not neighbors:
+        return float("inf")
+    elif vert2 in neighbors:
+        return 1
+    else:
+        new_prev = prev + [vert1]
+        return 1 + min(
+            graph_distance(graph, neighbor, vert2, new_prev)
+            for neighbor in neighbors
+        )
+
+
 def has_ind(lst: VyList, ind: int) -> bool:
     """Whether or not the list is long enough for that index"""
     if isinstance(lst, LazyList):
@@ -451,14 +478,17 @@ def make_equation(eqn: str) -> sympy:
     return sympy.Eq(make_expression(eqn[0]), make_expression(eqn[1]))
 
 
+# Deleted until we can fix bugs
+"""
 def make_expression(expr: str) -> sympy:
-    """Turns a string into a nice sympy expression"""
+    """ """Turns a string into a nice sympy expression""" """
     transformations = standard_transformations + (
         implicit_multiplication_application,
         convert_xor,
     )
 
     return sympy.parse_expr(expr, transformations=transformations)
+"""
 
 
 def max_by(vec: VyList, key=lambda x: x, cmp=None, ctx=DEFAULT_CTX):
@@ -1003,8 +1033,22 @@ def vy_eval(item: str, ctx: Context) -> Any:
 @lazylist
 def vy_map(function, vector, ctx: Context = DEFAULT_CTX):
     """Apply function to every element of vector"""
+    idx = 0
+    arity = (
+        function.stored_arity
+        if hasattr(function, "stored_arity")
+        else (function.arity if hasattr(function, "arity") else None)
+    )
     for element in iterable(vector, range, ctx=ctx):
-        yield safe_apply(function, element, ctx=ctx)
+        if not arity or arity == 1:
+            yield safe_apply(function, element, ctx=ctx)
+        elif arity == 2:
+            yield safe_apply(function, element, idx, ctx=ctx)
+        elif arity == 3:
+            yield safe_apply(function, element, idx, vector, ctx=ctx)
+        else:
+            yield safe_apply(function, element, ctx=ctx)
+        idx += 1
 
 
 def vyxalify(value: Any) -> Any:
